==> zio-aws-memorydb_2.12-5.17.129.2-sources.jar: zio/aws/memorydb/model/DeleteSubnetGroupResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteSubnetGroupResponse(
    subnetGroup: Option[zio.aws.memorydb.model.SubnetGroup] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse = {
    import DeleteSubnetGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
      .builder()
      .optionallyWith(subnetGroup.map(value => value.buildAwsValue()))(
        _.subnetGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.DeleteSubnetGroupResponse.ReadOnly =
    zio.aws.memorydb.model.DeleteSubnetGroupResponse.wrap(buildAwsValue())
}
object DeleteSubnetGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DeleteSubnetGroupResponse =
      zio.aws.memorydb.model
        .DeleteSubnetGroupResponse(subnetGroup.map(value => value.asEditable))
    def subnetGroup: Option[zio.aws.memorydb.model.SubnetGroup.ReadOnly]
    def getSubnetGroup
        : ZIO[Any, AwsError, zio.aws.memorydb.model.SubnetGroup.ReadOnly] =
      AwsError.unwrapOptionField("subnetGroup", subnetGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
  ) extends zio.aws.memorydb.model.DeleteSubnetGroupResponse.ReadOnly {
    override val subnetGroup
        : Option[zio.aws.memorydb.model.SubnetGroup.ReadOnly] = scala
      .Option(impl.subnetGroup())
      .map(value => zio.aws.memorydb.model.SubnetGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
  ): zio.aws.memorydb.model.DeleteSubnetGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-memorydb_2.12-5.17.209.1-sources.jar: zio/aws/memorydb/model/DeleteSubnetGroupResponse.scala <==
package zio.aws.memorydb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteSubnetGroupResponse(
    subnetGroup: Optional[zio.aws.memorydb.model.SubnetGroup] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse = {
    import DeleteSubnetGroupResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
      .builder()
      .optionallyWith(subnetGroup.map(value => value.buildAwsValue()))(
        _.subnetGroup
      )
      .build()
  }
  def asReadOnly: zio.aws.memorydb.model.DeleteSubnetGroupResponse.ReadOnly =
    zio.aws.memorydb.model.DeleteSubnetGroupResponse.wrap(buildAwsValue())
}
object DeleteSubnetGroupResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.memorydb.model.DeleteSubnetGroupResponse =
      zio.aws.memorydb.model
        .DeleteSubnetGroupResponse(subnetGroup.map(value => value.asEditable))
    def subnetGroup: Optional[zio.aws.memorydb.model.SubnetGroup.ReadOnly]
    def getSubnetGroup
        : ZIO[Any, AwsError, zio.aws.memorydb.model.SubnetGroup.ReadOnly] =
      AwsError.unwrapOptionField("subnetGroup", subnetGroup)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
  ) extends zio.aws.memorydb.model.DeleteSubnetGroupResponse.ReadOnly {
    override val subnetGroup
        : Optional[zio.aws.memorydb.model.SubnetGroup.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.subnetGroup())
        .map(value => zio.aws.memorydb.model.SubnetGroup.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.memorydb.model.DeleteSubnetGroupResponse
  ): zio.aws.memorydb.model.DeleteSubnetGroupResponse.ReadOnly = new Wrapper(
    impl
  )
}
